@@ -223,11 +223,7 @@ def upload(connection_or_endpoint, image_id, image_file, key,
         command_line = [image_tool_path,
                         '--id', image_id,
                         '--format', 'NFI',
-                        '--compression', 'LZ4',
-                        '--cipher', 'AES',
-                        '--mode', 'CTR',
                         '--key', b64encode(key),
-                        '--digest', 'SHA2_256',
                         '--machine',  # hidden option request machine-readable output
                         image_file,
                         destination]
